@@ -3,7 +3,7 @@
 import unittest
 
 import logging
-import mock
+from unittest import mock
 import requests_mock
 
 from certbot.errors import PluginError
@@ -15,10 +15,10 @@ from certbot.plugins import dns_test_common
 from certbot.plugins.dns_test_common import DOMAIN
 from certbot.tests import util as test_util
 
-from certbot_dns_infomaniak.dns_infomaniak import Authenticator
 from certbot_dns_infomaniak.dns_infomaniak import _APIDomain
 
 logger = logging.getLogger(__name__)
+logger.setLevel(logging.DEBUG)
 
 
 FAKE_TOKEN = "xxxx"
@@ -29,15 +29,16 @@ class AuthenticatorTest(
 ):
     """Class to test the Authenticator class"""
     def setUp(self):
-        super().setUp()
+        super(AuthenticatorTest, self).setUp()
 
         self.config = mock.MagicMock()
 
         os.environ["INFOMANIAK_API_TOKEN"] = FAKE_TOKEN
 
+        from certbot_dns_infomaniak.dns_infomaniak import Authenticator
         self.auth = Authenticator(self.config, "infomaniak")
 
-        self.mock_client = mock.MagicMock()
+        self.mock_client = mock.MagicMock(default_propagation_seconds=15)
         # _get_ispconfig_client | pylint: disable=protected-access
         self.auth._api_client = mock.MagicMock(return_value=self.mock_client)
 
